@@ -2,12 +2,11 @@
 #
 # @package      hubzero-submit-distributor
 # @file         monitorTunnelR.py
-# @author       Steve Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
+# @author       Steven Clark <clarks@purdue.edu>
+# @copyright    Copyright (c) 2004-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2011 Purdue University
-# All rights reserved.
+# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,7 +24,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 # ----------------------------------------------------------------------
 #  monitorTunnelR.py
@@ -34,7 +33,7 @@
 #
 import sys
 
-from RemoteTunnelMonitor import RemoteTunnelMonitor
+from hubzero.submit.RemoteTunnelMonitor import RemoteTunnelMonitor
 
 TUNNELMONITORHOST = ""
 TUNNELMONITORPORT = 5729
@@ -60,3 +59,4 @@ def monitorTunnelR():
 if __name__ == '__main__':
    monitorTunnelR()
 
+
